TraitsUI |version| Demos
==========================

.. toctree::
    :maxdepth: 3

This section contains links to a number of TraitsUI demos.

.. warning:: Some of the examples in this section may be out of date. We are in the process of updating them to the latest version of TraitsUI.

Standard Editors
------------------

- :github-demo:`BooleanEditor <Standard_Editors/BooleanEditor_demo.py>`
- :github-demo:`ButtonEditor <Standard_Editors/ButtonEditor_demo.py>`
- :github-demo:`CSVListEditor <Standard_Editors/CSVListEditor_demo.py>`
- :github-demo:`CheckListEditor <Standard_Editors/CheckListEditor_demo.py>`
- :github-demo:`CheckListEditor (simple) <Standard_Editors/CheckListEditor_simple_demo.py>`
- :github-demo:`CodeEditor <Standard_Editors/CodeEditor_demo.py>`
- :github-demo:`ColorEditor <Standard_Editors/ColorEditor_demo.py>`
- :github-demo:`CompoundEditor <Standard_Editors/CompoundEditor_demo.py>`
- :github-demo:`DirectoryEditor <Standard_Editors/DirectoryEditor_demo.py>`
- :github-demo:`EnumEditor <Standard_Editors/EnumEditor_demo.py>`
- :github-demo:`FileEditor <Standard_Editors/FileEditor_demo.py>`
- :github-demo:`FontEditor <Standard_Editors/FontEditor_demo.py>`
- :github-demo:`HTMLEditor <Standard_Editors/HTMLEditor_demo.py>`
- :github-demo:`ImageEnumEditor <Standard_Editors/ImageEnumEditor_demo.py>`
- :github-demo:`InstanceEditor <Standard_Editors/InstanceEditor_demo.py>`
- :github-demo:`ListEditor <Standard_Editors/ListEditor_demo.py>`
- :github-demo:`RGBColorEditor <Standard_Editors/RGBColorEditor_demo.py>`
- :github-demo:`RangeEditor <Standard_Editors/RangeEditor_demo.py>`
- :github-demo:`SetEditor <Standard_Editors/SetEditor_demo.py>`
- :github-demo:`TableEditor <Standard_Editors/TableEditor_demo.py>`
- :github-demo:`TextEditor <Standard_Editors/TextEditor_demo.py>`
- :github-demo:`TitleEditor <Standard_Editors/TitleEditor_demo.py>`
- :github-demo:`TreeEditor <Standard_Editors/TreeEditor_demo.py>`
- :github-demo:`TupleEditor <Standard_Editors/TupleEditor_demo.py>`

Advanced Demos
--------------
- :github-demo:`Adapted TreeEditor <Advanced/Adapted_tree_editor_demo.py>`
- :github-demo:`Apply/Revert Handler <Advanced/Apply_Revert_handler_demo.py>`
- :github-demo:`Table (read-only, auto-edit table column) <Advanced/Auto_editable_readonly_table_cells.py>`
- :github-demo:`TabularEditor (auto-update) <Advanced/Auto_update_TabularEditor_demo.py>`
- :github-demo:`DateEditor <Advanced/Date_editor_demo.py>`
- :github-demo:`Dynamic EnumEditor <Advanced/Dynamic_EnumEditor_demo.py>`
- :github-demo:`Dynamic Range Editor <Advanced/Dynamic_range_trait_and_editor.py>`
- :github-demo:`Dynamic Views <Advanced/Dynamic_views_demo.py>`
- :github-demo:`HDF5 Tree <Advanced/HDF5_tree_demo.py>`
- :github-demo:`History <Advanced/History_demo.py>`
- :github-demo:`Invalid state handling <Advanced/Invalid_state_handling.py>`
- :github-demo:`ListStrEditor <Advanced/ListStrEditor_demo.py>`
- :github-demo:`ListEditor <Advanced/List_editors_demo.py>`
- :github-demo:`ListEditor (notebook tabs) <Advanced/List_editor_notebook_selection_demo.py>`
- :github-demo:`MVC <Advanced/MVC_demo.py>`
- :github-demo:`Multi-selection string list <Advanced/Multi_select_string_list.py>`
- :github-demo:`Multithread <Advanced/Multi_thread_demo.py>`
- :github-demo:`Multithread 2 <Advanced/Multi_thread_demo_2.py>`
- :github-demo:`NumPy array TabularEditor <Advanced/NumPy_array_tabular_editor_demo.py>`
- :github-demo:`NumPy ArrayViewEditor <Advanced/NumPy_array_view_editor_demo.py>`
- :github-demo:`Popup Dialog <Advanced/Popup_Dialog_demo.py>`
- :github-demo:`Property List <Advanced/Property_List_demo.py>`
- :github-demo:`ScrubberEditor<Advanced/Scrubber_editor_demo.py>`
- :github-demo:`Settable cached property <Advanced/Settable_cached_property.py>`
- :github-demo:`Statusbar <Advanced/Statusbar_demo.py>`
- :github-demo:`StringListEditor <Advanced/String_list_ui_editor.py>`
- :github-demo:`TableEditor (with checkbox column) <Advanced/Table_editor_with_checkbox_column.py>`
- :github-demo:`TableEditor (with context menu) <Advanced/Table_editor_with_context_menu_demo.py>`
- :github-demo:`TableEditor (with live search and cell) <Advanced/Table_editor_with_live_search_and_cell_editor.py>`
- :github-demo:`TabularEditor <Advanced/Tabular_editor_demo.py>`
- :github-demo:`TimeEditor <Advanced/Time_editor_demo.py>`
